# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .computer_action import ComputerAction

__all__ = ["ComputerActionList"]

ComputerActionList: TypeAlias = List[ComputerAction]
