# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from ..responses.response_input_image import ResponseInputImage

__all__ = ["InputImageContent"]

InputImageContent = ResponseInputImage
